@@ -17,12 +17,83 @@ from vega.cli.templates import (
     render_cli_command_simple,
     render_event,
     render_event_handler,
+    render_listener,
     render_template,
+    # CQRS
+    render_cqrs_handler,
+    render_cqrs_command,
+    render_cqrs_query,
+    render_cqrs_response,
+    # DDD
+    render_aggregate,
+    render_value_object,
+    render_context_init,
 )
 from vega.cli.scaffolds import create_fastapi_scaffold
 from vega.cli.utils import to_snake_case, to_pascal_case
 
 
+def _detect_bounded_context(project_root: Path) -> str | None:
+    """
+    Detect which bounded context we're in based on current directory or prompt user.
+
+    Returns:
+        Context name if found, None if lib/ doesn't exist (legacy structure)
+    """
+    lib_path = project_root / "lib"
+    if not lib_path.exists():
+        return None  # Legacy structure
+
+    # Try to detect context from current working directory
+    try:
+        cwd = Path.cwd()
+        relative = cwd.relative_to(lib_path)
+        if relative.parts:
+            return relative.parts[0]
+    except (ValueError, IndexError):
+        pass
+
+    # Prompt user to select context
+    contexts = [d.name for d in lib_path.iterdir()
+                if d.is_dir() and not d.name.startswith('_') and d.name != 'shared']
+
+    if not contexts:
+        click.echo(click.style("ERROR: No bounded contexts found in lib/", fg='red'))
+        click.echo("Create a context first with: vega generate context <name>")
+        return None
+
+    if len(contexts) == 1:
+        click.echo(f"Using context: {click.style(contexts[0], fg='cyan')}")
+        return contexts[0]
+
+    click.echo("\nAvailable contexts:")
+    for i, ctx in enumerate(contexts, 1):
+        click.echo(f"  {i}. {ctx}")
+
+    try:
+        choice = click.prompt("Select context", type=click.IntRange(1, len(contexts)))
+        return contexts[choice - 1]
+    except (click.Abort, KeyboardInterrupt):
+        click.echo("\nCancelled.")
+        return None
+
+
+def _get_context_base_path(project_root: Path, context: str | None) -> Path:
+    """
+    Get base path for generating components.
+
+    Args:
+        project_root: Root of the project
+        context: Bounded context name (None for legacy structure)
+
+    Returns:
+        Base path where components should be created
+    """
+    if context is None:
+        return project_root  # Legacy structure
+    return project_root / "lib" / context
+
+
 def _resolve_implementation_names(class_name: str, implementation: str) -> tuple[str, str]:
     """Derive implementation class and file names from flag input."""
     impl_pascal = to_pascal_case(implementation) or "Impl"
@@ -63,10 +134,15 @@ def generate_component(
     class_name = to_pascal_case(name)
     implementation = implementation.strip() if implementation else None
 
+    # Handle aliases
     if component_type == 'repo':
         component_type = 'repository'
     if component_type in {'event-handler', 'subscriber'}:
         component_type = 'event_handler'
+    if component_type == 'value-object':
+        component_type = 'value_object'
+    if component_type == 'domain-event':
+        component_type = 'event'
 
     suffixes = {
         "repository": "Repository",
@@ -74,10 +150,10 @@ def generate_component(
         "mediator": "Mediator",
     }
 
-    if implementation and component_type not in {'repository', 'service'}:
+    if implementation and component_type not in {'repository', 'service', 'interactor'}:
         click.echo(
             click.style(
-                "WARNING: Implementation option is only supported for repositories and services",
+                "WARNING: Implementation option is only supported for repositories, services, and interactors (as CQRS type)",
                 fg='yellow',
             )
         )
@@ -92,14 +168,32 @@ def generate_component(
 
     file_name = to_snake_case(class_name)
 
-    if component_type == 'entity':
+    # DDD generators (context-aware)
+    if component_type == 'context':
+        _generate_context(project_root, project_name, name)
+    elif component_type == 'aggregate':
+        _generate_aggregate(project_root, project_name, class_name, file_name)
+    elif component_type == 'value_object':
+        _generate_value_object(project_root, project_name, class_name, file_name)
+    # CQRS generators
+    elif component_type == 'command':
+        # Default: CQRS command handler
+        # With --impl=cli: CLI command
+        if implementation and implementation.lower() == 'cli':
+            _generate_command(project_root, project_name, name, None)
+        else:
+            _generate_interactor(project_root, project_name, class_name, file_name, 'COMMAND')
+    elif component_type == 'query':
+        _generate_interactor(project_root, project_name, class_name, file_name, 'QUERY')
+    # Existing generators
+    elif component_type == 'entity':
         _generate_entity(project_root, project_name, class_name, file_name)
     elif component_type == 'repository':
         _generate_repository(project_root, project_name, class_name, file_name, implementation)
     elif component_type == 'service':
         _generate_service(project_root, project_name, class_name, file_name, implementation)
     elif component_type == 'interactor':
-        _generate_interactor(project_root, project_name, class_name, file_name)
+        _generate_interactor(project_root, project_name, class_name, file_name, implementation)
     elif component_type == 'mediator':
         _generate_mediator(project_root, project_name, class_name, file_name)
     elif component_type == 'router':
@@ -110,26 +204,36 @@ def generate_component(
         _generate_sqlalchemy_model(project_root, project_name, class_name, file_name)
     elif component_type == 'webmodel':
         _generate_web_models(project_root, project_name, name, is_request, is_response)
-    elif component_type == 'command':
+    elif component_type == 'cli_command':
         _generate_command(project_root, project_name, name, implementation)
     elif component_type == 'event':
         _generate_event(project_root, project_name, class_name, file_name)
     elif component_type == 'event_handler':
         _generate_event_handler(project_root, project_name, class_name, file_name)
+    elif component_type == 'listener':
+        _generate_listener(project_root, project_name, class_name, file_name)
+    else:
+        click.echo(click.style(f"ERROR: Unknown component type: {component_type}", fg='red'))
+        click.echo("Supported types: context, aggregate, value-object, command, query, entity, repository, service, etc.")
 
 
 def _generate_entity(project_root: Path, project_name: str, class_name: str, file_name: str):
-    """Generate domain entity"""
+    """Generate domain entity (context-aware)"""
+    context = _detect_bounded_context(project_root)
+    if context is None and (project_root / "lib").exists():
+        return  # Error already shown
 
-    file_path = project_root / "domain" / "entities" / f"{file_name}.py"
+    base_path = _get_context_base_path(project_root, context)
+    file_path = base_path / "domain" / "entities" / f"{file_name}.py"
 
     if file_path.exists():
         click.echo(click.style(f"ERROR: Error: {file_path} already exists", fg='red'))
         return
 
+    file_path.parent.mkdir(parents=True, exist_ok=True)
     content = render_entity(class_name)
-
     file_path.write_text(content)
+
     click.echo(f"+ Created {click.style(str(file_path.relative_to(project_root)), fg='green')}")
 
 
@@ -140,20 +244,25 @@ def _generate_repository(
     file_name: str,
     implementation: str | None = None,
 ):
-    """Generate repository interface"""
+    """Generate repository interface (context-aware)"""
+    context = _detect_bounded_context(project_root)
+    if context is None and (project_root / "lib").exists():
+        return  # Error already shown
+
+    base_path = _get_context_base_path(project_root, context)
 
     # Remove 'Repository' suffix if present to get entity name
     entity_name = class_name[:-len('Repository')] if class_name.endswith('Repository') else class_name
     entity_file = to_snake_case(entity_name)
 
-    file_path = project_root / "domain" / "repositories" / f"{file_name}.py"
+    file_path = base_path / "domain" / "repositories" / f"{file_name}.py"
 
     if file_path.exists():
         click.echo(click.style(f"ERROR: Error: {file_path} already exists", fg='red'))
         return
 
     # Check if entity exists
-    entity_path = project_root / "domain" / "entities" / f"{entity_file}.py"
+    entity_path = base_path / "domain" / "entities" / f"{entity_file}.py"
     if not entity_path.exists():
         click.echo(
             click.style(
@@ -169,15 +278,17 @@ def _generate_repository(
             click.echo(click.style(f"ERROR: Cannot create repository without entity {entity_name}", fg='red'))
             return
 
+    file_path.parent.mkdir(parents=True, exist_ok=True)
     content = render_repository_interface(class_name, entity_name, entity_file)
-
     file_path.write_text(content)
+
     click.echo(f"+ Created {click.style(str(file_path.relative_to(project_root)), fg='green')}")
 
     # Suggest next steps
+    infra_path = "lib/{context}/infrastructure/repositories/" if context else "infrastructure/repositories/"
     click.echo(f"\n💡 Next steps:")
     click.echo(f"   1. Create entity: vega generate entity {entity_name}")
-    click.echo(f"   2. Implement repository in infrastructure/repositories/")
+    click.echo(f"   2. Implement repository in {infra_path}")
     click.echo(f"   3. Register in config.py SERVICES dict")
 
     if implementation:
@@ -188,6 +299,7 @@ def _generate_repository(
             entity_name,
             entity_file,
             implementation,
+            context,
         )
 
 
@@ -198,20 +310,26 @@ def _generate_service(
     file_name: str,
     implementation: str | None = None,
 ):
-    """Generate service interface"""
+    """Generate service interface (context-aware)"""
+    context = _detect_bounded_context(project_root)
+    if context is None and (project_root / "lib").exists():
+        return  # Error already shown
 
-    file_path = project_root / "application" / "services" / f"{file_name}.py"
+    base_path = _get_context_base_path(project_root, context)
+
+    # Services go in domain layer for DDD (domain services)
+    # Or in application layer for application services
+    # Default to domain for now
+    file_path = base_path / "domain" / "repositories" / f"{file_name}.py"
 
     if file_path.exists():
         click.echo(click.style(f"ERROR: Error: {file_path} already exists", fg='red'))
         return
 
-    # Ensure directory exists
     file_path.parent.mkdir(parents=True, exist_ok=True)
-
     content = render_service_interface(class_name)
-
     file_path.write_text(content)
+
     click.echo(f"+ Created {click.style(str(file_path.relative_to(project_root)), fg='green')}")
 
     click.echo(f"\n💡 Next steps:")
@@ -227,34 +345,97 @@ def _generate_service(
         )
 
 
-def _generate_interactor(project_root: Path, project_name: str, class_name: str, file_name: str):
-    """Generate interactor (use case)"""
+def _generate_interactor(project_root: Path, project_name: str, class_name: str, file_name: str, cqrs_type: str | None = None):
+    """Generate interactor (use case) with CQRS pattern"""
 
-    # Try to infer entity from name (e.g., CreateUser -> User)
-    entity_name = class_name
-    for prefix in ['Create', 'Update', 'Delete', 'Get', 'List', 'Find']:
-        if class_name.startswith(prefix):
-            entity_name = class_name[len(prefix):]
-            break
+    # If no CQRS type specified, ask the user
+    if not cqrs_type:
+        cqrs_type = click.prompt(
+            "CQRS type",
+            type=click.Choice(['command', 'query'], case_sensitive=False),
+            default='command'
+        ).lower()
 
-    entity_file = to_snake_case(entity_name)
+    # Determine layer folder (commands or queries)
+    layer_folder = 'commands' if cqrs_type == 'command' else 'queries'
+    handler_type = 'COMMAND' if cqrs_type == 'command' else 'QUERY'
 
-    file_path = project_root / "application" / "interactors" / f"{file_name}.py"
+    # Folder name for the interactor (e.g., CreateUser - keep PascalCase)
+    folder_name = class_name
 
-    if file_path.exists():
-        click.echo(click.style(f"ERROR: Error: {file_path} already exists", fg='red'))
+    # Create the interactor directory
+    interactor_dir = project_root / "application" / layer_folder / class_name
+
+    if interactor_dir.exists():
+        click.echo(click.style(f"ERROR: Error: {interactor_dir.relative_to(project_root)} already exists", fg='red'))
         return
 
-    # Ensure directory exists
-    file_path.parent.mkdir(parents=True, exist_ok=True)
+    interactor_dir.mkdir(parents=True, exist_ok=True)
 
-    content = render_interactor(class_name, entity_name, entity_file)
+    # Prepare file names and class names
+    input_file = f"{cqrs_type}"  # command.py or query.py
+    input_class = f"{class_name}{cqrs_type.capitalize()}"  # CreateUserCommand or GetUserQuery
+    input_var = cqrs_type  # command or query
+    response_file = "response"
+    response_class = f"{class_name}Result"
 
-    file_path.write_text(content)
-    click.echo(f"+ Created {click.style(str(file_path.relative_to(project_root)), fg='green')}")
+    # Ask for description
+    description = click.prompt("Description", default=f"{class_name} {cqrs_type}")
 
-    click.echo(f"\n💡 Usage:")
-    click.echo(f"   result = await {class_name}(param=value)")
+    # Generate handler.py
+    handler_content = render_cqrs_handler(
+        class_name=class_name,
+        handler_type=handler_type,
+        layer_folder=layer_folder,
+        folder_name=folder_name,
+        input_file=input_file,
+        input_class=input_class,
+        input_var=input_var,
+        response_file=response_file,
+        response_class=response_class,
+        description=description,
+    )
+    handler_file = interactor_dir / "handler.py"
+    handler_file.write_text(handler_content)
+    click.echo(f"+ Created {click.style(str(handler_file.relative_to(project_root)), fg='green')}")
+
+    # Generate command.py or query.py
+    if cqrs_type == 'command':
+        input_content = render_cqrs_command(class_name, description)
+    else:
+        input_content = render_cqrs_query(class_name, description)
+
+    input_file_path = interactor_dir / f"{input_file}.py"
+    input_file_path.write_text(input_content)
+    click.echo(f"+ Created {click.style(str(input_file_path.relative_to(project_root)), fg='green')}")
+
+    # Generate response.py
+    response_content = render_cqrs_response(class_name, description)
+    response_file_path = interactor_dir / "response.py"
+    response_file_path.write_text(response_content)
+    click.echo(f"+ Created {click.style(str(response_file_path.relative_to(project_root)), fg='green')}")
+
+    # Create __init__.py for easier imports
+    init_content = f'''"""{ class_name} {cqrs_type} - CQRS Pattern"""
+from .handler import {class_name}Handler
+from .{input_file} import {input_class}
+from .response import {response_class}
+
+__all__ = [
+    "{class_name}Handler",
+    "{input_class}",
+    "{response_class}",
+]
+'''
+    init_file = interactor_dir / "__init__.py"
+    init_file.write_text(init_content)
+    click.echo(f"+ Created {click.style(str(init_file.relative_to(project_root)), fg='green')}")
+
+    # Usage instructions
+    click.echo(f"\nUsage:")
+    click.echo(f"   from application.{layer_folder}.{class_name} import {class_name}Handler, {input_class}")
+    click.echo(f"   {input_var} = {input_class}(...)  # Add your parameters")
+    click.echo(f"   result = await {class_name}Handler({input_var})")
 
 
 def _generate_mediator(project_root: Path, project_name: str, class_name: str, file_name: str):
@@ -282,10 +463,13 @@ def _generate_infrastructure_repository(
     entity_name: str,
     entity_file: str,
     implementation: str,
+    context: str | None = None,
 ) -> None:
-    """Generate infrastructure repository implementation extending the domain interface."""
+    """Generate infrastructure repository implementation (context-aware)."""
     impl_class, impl_file = _resolve_implementation_names(interface_class_name, implementation)
-    file_path = project_root / "infrastructure" / "repositories" / f"{impl_file}.py"
+
+    base_path = _get_context_base_path(project_root, context)
+    file_path = base_path / "infrastructure" / "repositories" / f"{impl_file}.py"
 
     if file_path.exists():
         click.echo(click.style(f"WARNING: Implementation {file_path} already exists", fg='yellow'))
@@ -400,14 +584,22 @@ def _register_router_in_init(project_root: Path, resource_file: str, resource_na
 
 
 def _generate_router(project_root: Path, project_name: str, name: str) -> None:
-    """Generate a Vega Web router for a resource"""
+    """Generate a Vega Web router for a resource (context-aware)"""
 
-    # Check if web folder exists
-    web_path = project_root / "presentation" / "web"
+    # Detect bounded context
+    context = _detect_bounded_context(project_root)
+    base_path = _get_context_base_path(project_root, context)
+
+    # Check if web folder exists in context
+    web_path = base_path / "presentation" / "web"
     if not web_path.exists():
         click.echo(click.style("ERROR: Web module not found", fg='red'))
-        click.echo("   Router generation requires Vega Web module")
-        click.echo("   Install it with: vega add web")
+        if context:
+            click.echo(f"   Router generation requires web structure in context '{context}'")
+            click.echo(f"   Create it: mkdir -p {web_path / 'routes'}")
+        else:
+            click.echo("   Router generation requires Vega Web module")
+            click.echo("   Install it with: vega add web")
         return
 
     # Convert name to appropriate formats
@@ -416,7 +608,7 @@ def _generate_router(project_root: Path, project_name: str, name: str) -> None:
 
     # Create routes directory if it doesn't exist
     routes_path = web_path / "routes"
-    routes_path.mkdir(exist_ok=True)
+    routes_path.mkdir(parents=True, exist_ok=True)
 
     # Check if __init__.py exists, create with auto-discovery if not
     init_file = routes_path / "__init__.py"
@@ -446,14 +638,21 @@ def _generate_router(project_root: Path, project_name: str, name: str) -> None:
 
 
 def _generate_web_models(project_root: Path, project_name: str, name: str, is_request: bool, is_response: bool) -> None:
-    """Generate Pydantic request or response model for Vega Web"""
+    """Generate Pydantic request or response model for Vega Web (context-aware)"""
 
-    # Check if web folder exists
-    web_path = project_root / "presentation" / "web"
+    # Detect bounded context
+    context = _detect_bounded_context(project_root)
+    base_path = _get_context_base_path(project_root, context)
+
+    # Check if web folder exists in context
+    web_path = base_path / "presentation" / "web"
     if not web_path.exists():
         click.echo(click.style("ERROR: Web module not found", fg='red'))
-        click.echo("   Model generation requires Vega Web module")
-        click.echo("   Install it with: vega add web")
+        if context:
+            click.echo(f"   Model generation requires web structure in context '{context}'")
+        else:
+            click.echo("   Model generation requires Vega Web module")
+            click.echo("   Install it with: vega add web")
         return
 
     # Validate flags
@@ -702,17 +901,21 @@ from infrastructure.models.{file_name} import {class_name}Model  # noqa: F401
 
 
 def _generate_command(project_root: Path, project_name: str, name: str, is_async: str | None = None) -> None:
-    """Generate a CLI command"""
-    
-    # Check if presentation/cli exists
-    cli_path = project_root / "presentation" / "cli"
+    """Generate a CLI command (context-aware)"""
+
+    # Detect bounded context
+    context = _detect_bounded_context(project_root)
+    base_path = _get_context_base_path(project_root, context)
+
+    # Check if presentation/cli exists in context
+    cli_path = base_path / "presentation" / "cli"
     if not cli_path.exists():
         cli_path.mkdir(parents=True, exist_ok=True)
         click.echo(f"+ Created {click.style(str(cli_path.relative_to(project_root)), fg='green')}")
-    
+
     # Create commands directory if it doesn't exist
     commands_path = cli_path / "commands"
-    commands_path.mkdir(exist_ok=True)
+    commands_path.mkdir(parents=True, exist_ok=True)
 
     # Check if __init__.py exists, create with auto-discovery if not
     init_file = commands_path / "__init__.py"
@@ -836,9 +1039,13 @@ def _generate_command(project_root: Path, project_name: str, name: str, is_async
 
 
 def _generate_event(project_root: Path, project_name: str, class_name: str, file_name: str):
-    """Generate a domain event."""
+    """Generate a domain event (context-aware)."""
+    context = _detect_bounded_context(project_root)
+    if context is None and (project_root / "lib").exists():
+        return  # Error already shown
 
-    events_path = project_root / "domain" / "events"
+    base_path = _get_context_base_path(project_root, context)
+    events_path = base_path / "domain" / "events"
     events_path.mkdir(parents=True, exist_ok=True)
 
     init_file = events_path / "__init__.py"
@@ -936,3 +1143,172 @@ def _generate_event_handler(project_root: Path, project_name: str, class_name: s
     click.echo(f"   1. Implement your handler in {handler_file.relative_to(project_root)}")
     click.echo("   2. Call events.register_all_handlers() during startup so auto-discovery loads it.")
     click.echo("   3. Run your workflow and verify the subscriber reacts to the event.")
+
+
+def _generate_listener(project_root: Path, project_name: str, class_name: str, file_name: str):
+    """Generate a job queue listener in infrastructure/listeners/"""
+
+    listeners_path = project_root / "infrastructure" / "listeners"
+    listeners_path.mkdir(parents=True, exist_ok=True)
+
+    init_file = listeners_path / "__init__.py"
+    if not init_file.exists():
+        init_file.write_text("")
+
+    listener_file = listeners_path / f"{file_name}.py"
+    if listener_file.exists():
+        click.echo(click.style(f"ERROR: {listener_file.relative_to(project_root)} already exists", fg='red'))
+        return
+
+    # Prompt for listener configuration
+    default_queue = to_snake_case(class_name.replace("Listener", ""))
+    queue_name = click.prompt("Queue name", default=default_queue)
+    workers = click.prompt("Number of workers", default=1, type=int)
+    auto_ack = click.confirm("Auto-acknowledge messages?", default=True)
+    visibility_timeout = click.prompt("Visibility timeout (seconds)", default=30, type=int)
+    retry_on_error = click.confirm("Retry on failure?", default=False)
+    max_retries = 3
+    if retry_on_error:
+        max_retries = click.prompt("Max retries", default=3, type=int)
+
+    # Determine if context parameter is needed (only when auto_ack=False)
+    has_context = not auto_ack
+
+    content = render_listener(
+        class_name=class_name,
+        queue_name=queue_name,
+        workers=workers,
+        auto_ack=auto_ack,
+        visibility_timeout=visibility_timeout,
+        retry_on_error=retry_on_error,
+        max_retries=max_retries,
+        has_context=has_context,
+    )
+
+    listener_file.write_text(content)
+    click.echo(f"+ Created {click.style(str(listener_file.relative_to(project_root)), fg='green')}")
+
+    click.echo("\nNext steps:")
+    click.echo(f"   1. Implement message handling logic in {listener_file.relative_to(project_root)}")
+    click.echo("   2. Configure queue driver in config.py (e.g., SQSDriver)")
+    click.echo(f"   3. Run: vega listener run")
+    click.echo(f"\nQueue configuration:")
+    click.echo(f"   - Queue: {queue_name}")
+    click.echo(f"   - Workers: {workers}")
+    click.echo(f"   - Auto-ack: {auto_ack}")
+    click.echo(f"   - Visibility timeout: {visibility_timeout}s")
+    if retry_on_error:
+        click.echo(f"   - Retry on error: Yes (max {max_retries} retries)")
+
+
+# DDD Generators
+
+
+def _generate_context(project_root: Path, project_name: str, context_name: str):
+    """Generate bounded context structure under lib/"""
+    lib_path = project_root / "lib"
+    if not lib_path.exists():
+        click.echo(click.style("ERROR: lib/ directory not found. This project uses legacy structure.", fg='red'))
+        click.echo("Create a new project with `vega init` to use DDD bounded contexts.")
+        return
+
+    context_path = lib_path / context_name
+    if context_path.exists():
+        click.echo(click.style(f"ERROR: Context '{context_name}' already exists", fg='red'))
+        return
+
+    click.echo(f"\n[*] Creating bounded context: {click.style(context_name, fg='green')}")
+
+    directories = [
+        "domain/aggregates",
+        "domain/entities",
+        "domain/value_objects",
+        "domain/events",
+        "domain/repositories",
+        "application/commands",
+        "application/queries",
+        "infrastructure/repositories",
+        "infrastructure/services",
+        "presentation/cli/commands",
+    ]
+
+    for directory in directories:
+        dir_path = context_path / directory
+        dir_path.mkdir(parents=True, exist_ok=True)
+        (dir_path / "__init__.py").write_text("")
+        click.echo(f"  + Created {context_name}/{directory}/")
+
+    # Context __init__.py with documentation
+    context_init = render_context_init(context_name, project_name)
+    (context_path / "__init__.py").write_text(context_init)
+
+    click.echo(f"\n{click.style('SUCCESS!', fg='green')} Bounded context '{context_name}' created")
+    click.echo(f"\nNext steps:")
+    click.echo(f"  vega generate aggregate Order          # In {context_name} context")
+    click.echo(f"  vega generate value-object Money")
+    click.echo(f"  vega generate command CreateOrder")
+
+
+def _generate_aggregate(project_root: Path, project_name: str, class_name: str, file_name: str):
+    """Generate aggregate root in domain/aggregates/"""
+    context = _detect_bounded_context(project_root)
+    if context is None and (project_root / "lib").exists():
+        return  # Error already shown by _detect_bounded_context
+
+    base_path = _get_context_base_path(project_root, context)
+
+    # Determine path based on structure
+    if context:
+        file_path = base_path / "domain" / "aggregates" / f"{file_name}.py"
+    else:
+        # Legacy: create in domain/entities (no aggregates folder in legacy)
+        file_path = base_path / "domain" / "entities" / f"{file_name}.py"
+        click.echo(click.style("WARNING: Using legacy structure. Consider migrating to lib/ structure.", fg='yellow'))
+
+    if file_path.exists():
+        click.echo(click.style(f"ERROR: {file_path} already exists", fg='red'))
+        return
+
+    file_path.parent.mkdir(parents=True, exist_ok=True)
+
+    content = render_aggregate(class_name)
+    file_path.write_text(content)
+
+    relative_path = file_path.relative_to(project_root)
+    click.echo(f"+ Created {click.style(str(relative_path), fg='green')}")
+    click.echo(f"\nNext steps:")
+    click.echo(f"  1. Add fields to {class_name}")
+    click.echo(f"  2. Implement business methods")
+    click.echo(f"  3. Add validation in __post_init__")
+
+
+def _generate_value_object(project_root: Path, project_name: str, class_name: str, file_name: str):
+    """Generate value object in domain/value_objects/"""
+    context = _detect_bounded_context(project_root)
+    if context is None and (project_root / "lib").exists():
+        return  # Error already shown
+
+    base_path = _get_context_base_path(project_root, context)
+
+    if context:
+        file_path = base_path / "domain" / "value_objects" / f"{file_name}.py"
+    else:
+        # Legacy: create in domain/entities
+        file_path = base_path / "domain" / "entities" / f"{file_name}.py"
+        click.echo(click.style("WARNING: Using legacy structure. Value objects created in domain/entities/", fg='yellow'))
+
+    if file_path.exists():
+        click.echo(click.style(f"ERROR: {file_path} already exists", fg='red'))
+        return
+
+    file_path.parent.mkdir(parents=True, exist_ok=True)
+
+    content = render_value_object(class_name)
+    file_path.write_text(content)
+
+    relative_path = file_path.relative_to(project_root)
+    click.echo(f"+ Created {click.style(str(relative_path), fg='green')}")
+    click.echo(f"\nValue object characteristics:")
+    click.echo(f"  - Immutable (frozen=True)")
+    click.echo(f"  - Equality by value, not identity")
+    click.echo(f"  - Self-validating (__post_init__)")
