@@ -7,6 +7,15 @@ from .components import (
     render_repository_interface,
     render_service_interface,
     render_web_package_init,
+    # CQRS templates
+    render_cqrs_handler,
+    render_cqrs_command,
+    render_cqrs_query,
+    render_cqrs_response,
+    # DDD templates
+    render_aggregate,
+    render_value_object,
+    render_context_init,
     # New Vega Web functions
     render_vega_app,
     render_vega_routes_init,
@@ -44,6 +53,7 @@ from .components import (
     render_event,
     render_event_handler,
     render_events_init,
+    render_listener,
 )
 from .loader import render_template
 
@@ -56,6 +66,15 @@ __all__ = [
     "render_infrastructure_repository",
     "render_infrastructure_service",
     "render_web_package_init",
+    # CQRS
+    "render_cqrs_handler",
+    "render_cqrs_command",
+    "render_cqrs_query",
+    "render_cqrs_response",
+    # DDD
+    "render_aggregate",
+    "render_value_object",
+    "render_context_init",
     # Vega Web
     "render_vega_app",
     "render_vega_routes_init",
@@ -93,5 +112,6 @@ __all__ = [
     "render_event",
     "render_event_handler",
     "render_events_init",
+    "render_listener",
     "render_template",
 ]
